@@ -14,8 +14,8 @@ event_header_fields_65 = [
     Field(8, "momentum_x", unit="GeV/c"),
     Field(9, "momentum_y", unit="GeV/c"),
     Field(10, "momentum_minus_z", unit="GeV/c"),
-    Field(11, "zenith", unit="deg"),
-    Field(12, "azimuth", unit="deg"),
+    Field(11, "zenith", unit="rad"),
+    Field(12, "azimuth", unit="rad"),
     Field(13, "n_random_sequences"),
     Field(13 + 1, "random_seeds", shape=(10, 3)),
     Field(44, "run_number"),
